function izpis_posredna( ...
    n, n0, u, r, ...
    v, l, l_izr, ...
    var0_apriori, var0_aposteriori, ...
    Sigma_vv, Sigma_li_li, Sigma_delta_delta, ...
    Y, alphaG, spodnja_meja_Y, zgornja_meja_Y, ...
    T, alphaT, zgornja_meja_T, ...
    nove_tocke_koordinate_XYZ, nove_tocke_imena, ...
    bazni_vektorji_imena ...
)
    % IZPIS_POSREDNA izpiše rezultate posredne izravnave GNSS mreže na strehi FGG
    %
    %   VHODNI PARAMETRI:
    %     n                         ... število vseh opazovanj
    %     n0                        ... minimalno število potrebnih opazovanj
    %     u                         ... število neznank
    %     r                         ... število nadštevilnih opazovanj
    %     v                         ... vektor popravkov opazovanj
    %     l                         ... vektor opazovanj
    %     l_izr                     ... vektor izravnanih opazovanj
    %     var0_apriori              ... referenčna varianca a-priori
    %     var0_aposteriori          ... referenčna varianca a-posteriori
    %     Sigma_vv                  ... kovariančna matrika popravkov opazovanj
    %     Sigma_li_li               ... kovariančna matrika izravnanih opazovanj
    %     Sigma_delta_delta         ... kovariančna matrika neznank
    %     Y                         ... globalni test modela - testna statistika
    %     alphaG                    ... globalni test modela - značilnost testa
    %     spodnja_meja_Y            ... globalni test modela - spodnja meja
    %     zgornja_meja_Y            ... globalni test modela - zgornja meja
    %     T                         ... Tau-test - vektor testnih statistik za posamezno opazovanje
    %                                   T = [T_dX1; T_dY1; T_dZ1; T_dX2; T_dY2; T_dZ2; T_dX3; T_dY3; T_dZ3; ...];
    %     alphaT                    ... Tau-test - značilnost testa
    %     zgornja_meja_T            ... Tau-test - zgornja meja
    %     nove_tocke_koordinate_XYZ ... matrika s koordinatami novih točk
    %                                   nove_tocke_koordinate_XYZ = [ X_FGG1    Y_FGG1    Z_FGG1
    %                                                                 X_FGG2    Y_FGG2    Z_FGG2
    %                                                                 X_FGG4    Y_FGG4    Z_FGG4 ]
    %     nove_tocke_imena          ... vektor z imeni novih točk
    %                                   nove_tocke_imena = ["FGG1"; "FGG2"; "FGG4"]
    %     bazni_vektorji_imena      ... vektor z imeni opazovanj (komponent baznih vektorjev)
    %                                   bazni_vektorji_imena = ["FGG4--FGG1-ΔX"; "FGG4--FGG1-ΔY"; "FGG4--FGG1-ΔZ"; ...]


    hline_d = repmat('=', 1, 80);
    fprintf('%s\n', hline_d);
    fprintf('================== POSREDNA IZRAVAVA GNSS MREŽE NA STREHI FGG ==================\n');
    fprintf('%s\n\n', hline_d);
    fprintf('------------------------------ PARAMETRI IZRAVNAVE -----------------------------\n');
    fprintf('n  = %2d\n', n);
    fprintf('n0 = %2d\n', n0);
    fprintf('u  = %2d\n', u);
    fprintf('r  = %2d\n', r);
    fprintf('\n');
    
    fprintf('------------------------------ IZRAVNANA OPAZOVANJA ----------------------------\n');
    fprintf('                       l      +       v      =      l_izr   +-   σl_izr    \n')
    fprintf('                      [m]            [m]             [m]          [m]\n')
    fprintf('-----------------------------------------------------------------------\n')
    for i = 1 : length(v)
        fprintf('%13s:  %11.5f   + %10.5f   = %11.5f  +- %8.5f\n', ...
            bazni_vektorji_imena(i), l(i), v(i), l_izr(i), sqrt(Sigma_li_li(i,i)));
    end
    fprintf('\n');
    
    fprintf('----------------------------- GLOBALNI TEST MODELA -----------------------------\n');
    fprintf('var0      = %9.4f mm2        (s0      = %9.4f mm)\n', var0_apriori*1e6, sqrt(var0_apriori*1e6));
    fprintf('var0_izr  = %9.4f mm2        (s0_izr  = %9.4f mm)\n', var0_aposteriori*1e6, sqrt(var0_aposteriori*1e6));
        if (spodnja_meja_Y < Y) && (Y < zgornja_meja_T)
            flag = "";
            trditev = sprintf("\nS tveganjem %.1f %%%% ne moremo trditi, da ??????????\n", alphaG*100);
        else
            flag = "***";
            trditev = sprintf("\nS tveganjem %.1f %%%% lahko trditmo, da ??????????\n", alphaG*100);
        end
    fprintf('Y         = %7.2f  %s\n', Y, flag);
    fprintf('Y_sp_meja = %7.2f\n', spodnja_meja_Y);
    fprintf('Y_zg_meja = %7.2f\n', zgornja_meja_Y);
    fprintf(trditev);
    fprintf('\n');
    
    fprintf('----------------------------------- TAU-TEST -----------------------------------\n');
    fprintf('α      =  %.2f %%\n', alphaT*100);                                           
    fprintf('T_krit = ±%.4f\n', zgornja_meja_T);
    fprintf('\n');
    fprintf('                   v        σv       Tv\n');
    fprintf('                  [mm]     [mm]       \n');
    fprintf('----------------------------------------\n')
    for i = 1 : length(v)
        if abs(T(i)) > zgornja_meja_T
            flag = "***";
        else
            flag = "";
        end
        fprintf('%13s:  %6.2f    %5.2f    %5.2f  %s\n', ...
            bazni_vektorji_imena(i), v(i)*1000, sqrt(Sigma_vv(i,i))*1000, abs(T(i)), flag);
    end
    fprintf('\n');
    
    fprintf('----------------------- OCENJENE KOORDINATE V D96-17/XYZ -----------------------\n');
    for i = 1 : size(nove_tocke_koordinate_XYZ, 1)
	    fprintf('%s    X   %14.4f m      σX   %4.1f mm\n', ...
            nove_tocke_imena(i), nove_tocke_koordinate_XYZ(i,1), sqrt(Sigma_delta_delta(3*i-2, 3*i-2))*1e3);
        fprintf('        Y   %14.4f m      σY   %4.1f mm\n', ...
            nove_tocke_koordinate_XYZ(i,2), sqrt(Sigma_delta_delta(3*i-1, 3*i-1))*1000);
        fprintf('        Z   %14.4f m      σZ   %4.1f mm\n', ...
            nove_tocke_koordinate_XYZ(i,3), sqrt(Sigma_delta_delta(3*i, 3*i))*1000);
        fprintf('\n')
    end
    
    fprintf('%s\n', hline_d);
end

